==> ejc-salary-api-3.0.0-20250116.033910-103-sources.jar: com/ejianc/business/salary/vo/RosterRecordVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 人员花名册-历史记录表
 * 
 * @author generator
 * 
 */
public class RosterRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String employeeCode; // 员工编码
    private Long userId; // 员工id
    private String userCode; // 员工编号
    private String userName; // 人员名称
    private Long orgId; // 单位id
    private String orgCode; // 单位编码
    private String orgName; // 单位名称
    private Long departmentId; // 部门id
    private String departmentCode; // 部门编码
    private String departmentName; // 部门名称
    private Long postId; // 岗位id
    private String postName; // 岗位
    private String jobLevelName; // 岗级
    private String idCard; // 身份证号
    private String sexName; // 性别
    private String userTypeName; // 人员类别
    private String mobilePhone; // 手机号码
    private String residencyTypeName; // 派驻类别
    private String educationName; // 最高学历
    private String titleName; // 最高职称
    private String socialDepartmentCode; // 社保缴纳单位编号
    private String socialDepartmentName; // 社保缴纳单位
    private String workYear; // 司龄
    private String sourceType; // 人员库
    private String bankName; // 开户行
    private String bankAccount; // 银行账户
    private String bankAddress; // 银行地址
    private Long syncDay; // 同步日期
    private Integer hrState; // 人员状态（1：启用，0：停用）
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public String getJobLevelName() {
        return jobLevelName;
    }

    public void setJobLevelName(String jobLevelName) {
        this.jobLevelName = jobLevelName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }
    public String getUserTypeName() {
        return userTypeName;
    }

    public void setUserTypeName(String userTypeName) {
        this.userTypeName = userTypeName;
    }
    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }
    public String getResidencyTypeName() {
        return residencyTypeName;
    }

    public void setResidencyTypeName(String residencyTypeName) {
        this.residencyTypeName = residencyTypeName;
    }
    public String getEducationName() {
        return educationName;
    }

    public void setEducationName(String educationName) {
        this.educationName = educationName;
    }
    public String getTitleName() {
        return titleName;
    }

    public void setTitleName(String titleName) {
        this.titleName = titleName;
    }
    public String getSocialDepartmentCode() {
        return socialDepartmentCode;
    }

    public void setSocialDepartmentCode(String socialDepartmentCode) {
        this.socialDepartmentCode = socialDepartmentCode;
    }
    public String getSocialDepartmentName() {
        return socialDepartmentName;
    }

    public void setSocialDepartmentName(String socialDepartmentName) {
        this.socialDepartmentName = socialDepartmentName;
    }
    public String getWorkYear() {
        return workYear;
    }

    public void setWorkYear(String workYear) {
        this.workYear = workYear;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    
}

==> ejc-salary-api-3.0.0-20251203.044519-199-sources.jar: com/ejianc/business/salary/vo/RosterRecordVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 人员花名册-历史记录表
 * 
 * @author generator
 * 
 */
public class RosterRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String employeeCode; // 员工编码
    private Long userId; // 员工id
    private String userCode; // 员工编号
    private String userName; // 人员名称
    private Long orgId; // 单位id
    private String orgCode; // 单位编码
    private String orgName; // 单位名称
    private Long departmentId; // 部门id
    private String departmentCode; // 部门编码
    private String departmentName; // 部门名称
    private Long postId; // 岗位id
    private String postName; // 岗位
    private String jobLevelName; // 岗级
    private String idCard; // 身份证号
    private String sexName; // 性别
    private String userTypeName; // 人员类别
    private String mobilePhone; // 手机号码
    private String residencyTypeName; // 派驻类别
    private String educationName; // 最高学历
    private String titleName; // 最高职称
    private String socialDepartmentCode; // 社保缴纳单位编号
    private String socialDepartmentName; // 社保缴纳单位
    private String workYear; // 司龄
    private String sourceType; // 人员库
    private String bankName; // 开户行
    private String bankAccount; // 银行账户
    private String bankAddress; // 银行地址
    private Long syncDay; // 同步日期
    private Integer hrState; // 人力状态（1：正常，2：删除）

    private List<RosterJobVO> rosterJobList = new ArrayList<>(); // 人员花名册-兼职库
    private List<RosterSocialSecurityVO> rosterSocialSecurityList = new ArrayList<>(); // 人员花名册-社保
    private List<RosterAccumulationFundVO> rosterAccumulationFundList = new ArrayList<>(); // 人员花名册-公积金
    private List<RosterAttendanceVO> rosterAttendanceList = new ArrayList<>(); // 人员花名册-出勤
    private List<RosterTransferVO> rosterTransferList = new ArrayList<>(); // 人员花名册-异动
    private List<RosterCertificateVO> rosterCertificateList = new ArrayList<>(); // 人员花名册-证书
    private Long bankId; // 开户行id
    private String bankCode; // 开户行code
    private Long socialCompanyId; // 社保承担公司id
    private String socialCompanyCode; // 社保承担公司编号
    private String companyName; // 社保承担公司
    private String errorMsg;
    private Long payOrgId; // 发放工资单位
    private String payOrgName; // 发放工资单位名称
    private String isOnlySocial; // 是否仅社保人员
    private String payOrgCode; // 发放工资单位

    @Override
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    @Override
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }

    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }

    public String getJobLevelName() {
        return jobLevelName;
    }

    public void setJobLevelName(String jobLevelName) {
        this.jobLevelName = jobLevelName;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }

    public String getUserTypeName() {
        return userTypeName;
    }

    public void setUserTypeName(String userTypeName) {
        this.userTypeName = userTypeName;
    }

    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }

    public String getResidencyTypeName() {
        return residencyTypeName;
    }

    public void setResidencyTypeName(String residencyTypeName) {
        this.residencyTypeName = residencyTypeName;
    }

    public String getEducationName() {
        return educationName;
    }

    public void setEducationName(String educationName) {
        this.educationName = educationName;
    }

    public String getTitleName() {
        return titleName;
    }

    public void setTitleName(String titleName) {
        this.titleName = titleName;
    }

    public String getSocialDepartmentCode() {
        return socialDepartmentCode;
    }

    public void setSocialDepartmentCode(String socialDepartmentCode) {
        this.socialDepartmentCode = socialDepartmentCode;
    }

    public String getSocialDepartmentName() {
        return socialDepartmentName;
    }

    public void setSocialDepartmentName(String socialDepartmentName) {
        this.socialDepartmentName = socialDepartmentName;
    }

    public String getWorkYear() {
        return workYear;
    }

    public void setWorkYear(String workYear) {
        this.workYear = workYear;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }

    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }

    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }

    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }

    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }

    public List<RosterJobVO> getRosterJobList() {
        return rosterJobList;
    }

    public void setRosterJobList(List<RosterJobVO> rosterJobList) {
        this.rosterJobList = rosterJobList;
    }

    public List<RosterSocialSecurityVO> getRosterSocialSecurityList() {
        return rosterSocialSecurityList;
    }

    public void setRosterSocialSecurityList(List<RosterSocialSecurityVO> rosterSocialSecurityList) {
        this.rosterSocialSecurityList = rosterSocialSecurityList;
    }

    public List<RosterAccumulationFundVO> getRosterAccumulationFundList() {
        return rosterAccumulationFundList;
    }

    public void setRosterAccumulationFundList(List<RosterAccumulationFundVO> rosterAccumulationFundList) {
        this.rosterAccumulationFundList = rosterAccumulationFundList;
    }

    public List<RosterAttendanceVO> getRosterAttendanceList() {
        return rosterAttendanceList;
    }

    public void setRosterAttendanceList(List<RosterAttendanceVO> rosterAttendanceList) {
        this.rosterAttendanceList = rosterAttendanceList;
    }

    public List<RosterTransferVO> getRosterTransferList() {
        return rosterTransferList;
    }

    public void setRosterTransferList(List<RosterTransferVO> rosterTransferList) {
        this.rosterTransferList = rosterTransferList;
    }

    public List<RosterCertificateVO> getRosterCertificateList() {
        return rosterCertificateList;
    }

    public void setRosterCertificateList(List<RosterCertificateVO> rosterCertificateList) {
        this.rosterCertificateList = rosterCertificateList;
    }

    public Long getBankId() {
        return bankId;
    }

    public void setBankId(Long bankId) {
        this.bankId = bankId;
    }

    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }

    public Long getSocialCompanyId() {
        return socialCompanyId;
    }

    public void setSocialCompanyId(Long socialCompanyId) {
        this.socialCompanyId = socialCompanyId;
    }

    public String getSocialCompanyCode() {
        return socialCompanyCode;
    }

    public void setSocialCompanyCode(String socialCompanyCode) {
        this.socialCompanyCode = socialCompanyCode;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public Long getPayOrgId() {
        return payOrgId;
    }

    public void setPayOrgId(Long payOrgId) {
        this.payOrgId = payOrgId;
    }

    public String getPayOrgName() {
        return payOrgName;
    }

    public void setPayOrgName(String payOrgName) {
        this.payOrgName = payOrgName;
    }

    public String getIsOnlySocial() {
        return isOnlySocial;
    }

    public void setIsOnlySocial(String isOnlySocial) {
        this.isOnlySocial = isOnlySocial;
    }

    public String getPayOrgCode() {
        return payOrgCode;
    }

    public void setPayOrgCode(String payOrgCode) {
        this.payOrgCode = payOrgCode;
    }
}
